@@ -162,6 +162,7 @@ def _prepare_postgresql_config_files(template,
         rendered_data = template.render(node=node,
                                         creds=credentials,
                                         ca_path=CA_PATH,
+                                        ca_key_path=CA_KEY_PATH,
                                         postgresql_cluster=postgresql_cluster)
         _create_config_file(node, rendered_data)
 
@@ -181,6 +182,7 @@ def _prepare_rabbitmq_config_files(template,
         rendered_data = template.render(node=node,
                                         creds=credentials,
                                         ca_path=CA_PATH,
+                                        ca_key_path=CA_KEY_PATH,
                                         join_cluster=join_cluster,
                                         rabbitmq_cluster=rabbitmq_cluster,
                                         load_balancer_ip=load_balancer_ip)
@@ -293,7 +295,7 @@ def _install_cloudify_remotely(instance):
 def _get_service_status_code(instance):
     """Checking the status code of the cfy_manager_install_<type> service."""
     result = instance.run_command(
-        'systemctl status {}'.format(instance.unit_name),
+        'systemctl status {} --no-pager'.format(instance.unit_name),
         use_sudo=True, hide_stdout=True, ignore_failure=True)
     return result.return_code
 
